@@ -83,6 +83,10 @@
 ## 2014-10-29   - more _rels bookkeepin improvements.
 ##              - Ignore writing empty text cells to worksheet
 ## 2015-03-07   - Replace deprecated strmatch
+## 2015-07-10   - Fix typo in duplicate worksheet names check (bug #45498)
+##    ''        - Change numeric write format to %0.15g (MS-Excel accepts that)
+##                to ensure 15 digits precision. Along the way aliminate
+##                expensive call to strtrim()
 
 function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_opts, obj_dims)
 
@@ -124,7 +128,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
              length (wsh_string <= 31))
         wsh_string = strrep (wsh_string, "Sheet", "Sheet_");
       endwhile
-      if (length (string) > 31)
+      if (length (wsh_string) > 31)
         error ("oct2xls: cannot add worksheet with a unique name\n");
       endif
       ## The sheet index number can't leave a gap in the stack, so:
@@ -449,7 +453,7 @@ function [ xls, rstatus ] = __OCT_oct2xlsx_sh__ (xls, wsh_number, arrdat, lims,
                lims(1, 1), lims(1, 2));
       for c = 1:columns (arrdat)
         if (0 == isnan (arrdat{r, c}))
-          fprintf (fid, sprintf ('<c r="%s%d" t="n"><v>%f</v></c>', ... 
+          fprintf (fid, sprintf ('<c r="%s%d" t="n"><v>%0.15g</v></c>', ... 
                    num2col (c+lims(1, 1)-1), r+lims(2, 1)-1, arrdat{r, c}));
         endif
       endfor
@@ -505,7 +509,7 @@ function [ xls, rstatus ] = __OCT_oct2xlsx_sh__ (xls, wsh_number, arrdat, lims,
             case 1                    ## Numeric
               ## t tag ("type") is omitted for numeric data ???
               ttag = ' t="n"';
-              val = ["<v>" strtrim(sprintf ("%25.10f", arrdat{ii, jj})) "</v>"];
+              val = ["<v>" (sprintf ("%0.15g", arrdat{ii, jj})) "</v>"];
             case 2                    ## Boolean
               ttag = ' t="b"';
               if (arrdat{ii, jj})
