@@ -76,6 +76,8 @@
 ## 2013-12-28 Added check for OpenXLS version 10
 ## 2013-12-29 Added gwt-servlet-deps.jar to OpenXLS dependencies
 ## 2014-04-24 Skip all Java checks if Octave was built w/o Java support
+## 2014-02-15 Move "xlsinterfaces.COM = 1" stanza down as last stmt in try
+##            block as stray COM calls seem to be possible
 
 function [xlsinterfaces] = getxlsinterfaces (xlsinterfaces)
 
@@ -122,8 +124,6 @@ function [xlsinterfaces] = getxlsinterfaces (xlsinterfaces)
     xlsinterfaces.COM = 0;
     try
       app = actxserver ("Excel.application");
-      ## If we get here, the call succeeded & COM works.
-      xlsinterfaces.COM = 1;
       ## Close Excel. Yep this is inefficient when we need only one r/w action,
       ## but it quickly pays off when we need to do more with the same file
       ## (+, MS-Excel code is in OS cache anyway after this call so no big deal)
@@ -136,6 +136,8 @@ function [xlsinterfaces] = getxlsinterfaces (xlsinterfaces)
         printf ("*; ");
         deflt = 1;
       endif
+      ## If we get here, the call succeeded & COM works.
+      xlsinterfaces.COM = 1;
     catch
       ## COM non-existent. Only print message if COM is explicitly requested (tmp1==[])
       if (! isempty (tmp1))
