@@ -149,6 +149,7 @@
 ##     ''     Be silent when creating new file
 ## 2015-04-24 Depending on supported interfaces, use .xls or .xlsx (OOXML)
 ##            if no suffix was specified
+## 2015-07-10 Fix typo preventing writing to .ods
 
 function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
 
@@ -246,7 +247,7 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
           ftype = 1;
         case {".xlsx", ".xlsm", ".xlsb"}          ## Zipped XML / OOXML. Catches xlsx, xlsb, xlsm
           ftype = 2;
-        case "ods"                                ## ODS 1.2 (Excel 2007+ & OOo/LO can read ODS)
+        case ".ods"                               ## ODS 1.2 (Excel 2007+ & OOo/LO can read ODS)
           ftype = 3;
         case ".gnumeric"                          ## Zipped XML / gnumeric
           ftype = 5;
