@@ -163,6 +163,8 @@
 ## 2014-04-15 More updates to texinfo header
 ## 2014-04-26 Fixed error messages (no traceback)
 ## 2015-03-06 Texinfo header update
+## 2015-03-13 Overhaul & fix csvread logic. Move unwind_protect block so that
+##            it's logic cannot be interrupted by a return stmt
 
 function [ numarr, txtarr, rawarr, lims ] = xlsread (fn, wsh, datrange, reqintf=[])
 
@@ -195,43 +197,50 @@ function [ numarr, txtarr, rawarr, lims ] = xlsread (fn, wsh, datrange, reqintf=
 		printf ("(BASIC (BIFF5) support request translated to JXL)\n");
 	endif
 
-	## Checks done. Get raw data into cell array "rawarr". xlsopen finds out
-	## what interface to use. If none found, just return as xlsopen will complain enough
-
-	unwind_protect	# Needed to catch COM errors & able to close stray Excel invocations
-    ## Get pointer array to Excel file
-    xls_ok = 0;
-    xls = xlsopen (fn, 0, reqintf);
-    if (! isempty (xls))
-      xls_ok = 1;
+	## Checks done. First check for .csv as that doesn't need xlsopen etc;
+  ## a convenience for lazy Matlab users (see bugs #40993 & #44511):
+  [~, ~, ext] = fileparts (fn);
+  if strcmpi (ext, ".csv")
+    if (isempty (datrange))
+      numarr = dlmread (fn, ",");
     else
-      ## Convenience for scripts from lazy Matlab users (see bug #40993):
-      [~, ~, ext] = fileparts (fn);
-      if strcmpi (fn, ".csv")
-        numarr = csvread (fn, 1, datrange);
+      numarr = dlmread (fn, ",", datrange);
+    endif
+    txtarr = rawarr = lims = [];
+    return
+
+  else
+    ## Get raw data into cell array "rawarr". xlsopen finds out what interface
+    ## to use. If none found, just return as xlsopen will complain enough.
+    unwind_protect	## Needed to catch COM errors & able to close stray Excel
+                    ## invocations
+      ## Get pointer array to spreadsheet file
+      xls_ok = 0;
+      xls = xlsopen (fn, 0, reqintf);
+      if (! isempty (xls))
+        xls_ok = 1;
       endif
-      return
-    endif
 
-    ## Get data from Excel file & return handle
-    [rawarr, xls, rstatus] = xls2oct (xls, wsh, datrange);
+      ## Get data from spreadsheet file & return handle
+      [rawarr, xls, rstatus] = xls2oct (xls, wsh, datrange);
 
-    ## Save some results before xls is wiped
-    rawlimits = xls.limits;
-    xtype = xls.xtype;
+      ## Save some results before xls is wiped
+      rawlimits = xls.limits;
+      xtype = xls.xtype;
 
-    if (rstatus)
-      [numarr, txtarr, lims] = parsecell (rawarr, rawlimits);
-    else
-      rawarr = {}; numarr = []; txtarr = {};
-    endif
+      if (rstatus)
+        [numarr, txtarr, lims] = parsecell (rawarr, rawlimits);
+      else
+        rawarr = {}; numarr = []; txtarr = {};
+      endif
 
-	unwind_protect_cleanup	
-    ## Close Excel file
-    if (xls_ok)
-      xls = xlsclose (xls);
-    endif
+    unwind_protect_cleanup	
+      ## Close Excel file
+      if (xls_ok)
+        xls = xlsclose (xls);
+      endif
 
-	end_unwind_protect
+    end_unwind_protect
+  endif
 
 endfunction
