@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -22,19 +22,21 @@
 ## spreadsheet file @var{filename} in cell range @var{range}. Gnumeric
 ## files can also be written.
 ##
-## @var{rstatus} returns 1 if write succeeded, 0 otherwise.
+## @var{rstatus} returns 1 if writing succeeded, 0 otherwise.
 ##
-## @var{filename} must be a valid .xls Excel file name (including file
-## name extension). If @var{filename} does not contain any directory path,
-## the file is saved in the current directory.
+## @var{filename} must be a valid Excel file name (including file
+## name extension).  If @var{filename} does not contain any directory path,
+## the file is saved in the current directory.  Writing .xlsm and .xlsb
+## is untested but may only reliably be possible with the COM and UNO
+## interfaces.
 ##
-## @var{arr} can be any 1D or 2D array containing numerical or character
-## data (cellstr) except complex. Mixed numeric/text arrays can only be
-## cell arrays.
+## @var{arr} can be any 1D or 2D array containing numerical, logical and/or
+## character data (cellstr) except complex.  Mixed numeric/text arrays can
+## only be cell arrays.
 ##
 ## If only 3 arguments are given, the 3rd is assumed to be a spreadsheet
-## range if it contains a ":" or is a completely empty string (corresponding
-## to A1:IV65336 for regular .xls or A1:XFD1048576 for OOXML .xlsx). The
+## range if it contains a ":" or is a completely empty string (interpreted
+## as A1:IV65336 for regular .xls or A1:XFD1048576 for OOXML .xlsx).  The
 ## 3rd argument is assumed to refer to a worksheet if it is a numeric value
 ## or a non-empty text string not containing ":"
 ##
@@ -60,21 +62,31 @@
 ##
 ## If @var{range} contains merged cells, only the elements of @var{arr}
 ## corresponding to the top or left Excel cells of those merged cells
-## will be written, other array cells corresponding to that cell will be
-## ignored.
+## will be written, other array cells corresponding to that merged cell
+## will be ignored. In other words, merged spreadsheet cells won't be
+## "unmerged".
 ##
+## As to the optional last argument @var{reqintf}: 
+## When no external support SW for spreadsheet I/O ('interface') is
+## installed (see below), xlsread can only write to .xlsx, .ods and
+## .gnumeric files using the default (built-in) 'OCT' interface.  If
+## external support SW is installed, xlswrite will try locate it
+## automatically and invoke it, allowing more file types to be written.
+## Multiple spreadsheet I/O 'interfaces' can be installed side-by-side;
+## xlswrite will then try to invoke the most suitable one depending
+## on file type.
 ## The optional last argument @var{reqintf} can be used to override 
-## the automatic selection by xlswrite of one interface out of the
-## supported ones: 'com' (ActiveX/Excel), 'poi' (Java/Apache POI), 'jxl'
-## (Java/JExcelAPI), 'uno' (Java/OpenOffice.org), or 'OCT' (native Octave
-## w/o any external support software). 'oxs' (Java/OpenXLS) has been
-## implemented but disabled for writing OOXML as it is too buggy; for
-## BIFF8 (Excel '97 .xls) it works reliably. For writing to OOXML files
-## (.xlsx) a value of 'com', 'poi', 'uno', or 'oct' must
-## be specified for @var{reqintf}. The value of @var{reqintf} is
-## case-insensitive. Multiple interfaces can be selected if entered as
-## a cell array of strings. Writing gnumeric files can only be done
-## with the OCT interface, selected automatically for those files.
+## that automatic selection by xlswrite.  Supported interfaces
+## comprise: 'com' (ActiveX/Excel), 'poi' (Java/Apache POI), 'jxl'
+## (Java/JExcelAPI), 'uno' (Java/OpenOffice.org), or 'oct' (native
+## Octave w/o any external support software).  'oxs' (Java/OpenXLS)
+## works reliably and fast for .xls (BIFF8) but has been disabled for
+## writing OOXML as that is too buggy.  For writing to OOXML files
+## (.xlsx) a value of 'com', 'poi', 'uno', or 'oct' must be specified
+## for @var{reqintf}.  The value of @var{reqintf} is case-insensitive.
+## Multiple interfaces can be selected if entered as a cell array of
+## strings.  Writing gnumeric files can only be done with the OCT
+## interface, it is selected automatically for that file type.
 ##
 ## xlswrite is a mere wrapper for various scripts which find out what
 ## Excel interface to use (COM, POI, etc) plus code to mimic the other
@@ -89,10 +101,12 @@
 ## Examples:
 ##
 ## @example
-##   status = xlswrite ('test4.xls', 'arr', 'Third_sheet', 'C3:AB40');
-##   (which adds the contents of array arr (any type) to range C3:AB40 
-##   in worksheet 'Third_sheet' in file test4.xls and returns a logical 
-##   True (= numerical 1) in status if al went well) 
+##   status = xlswrite ...
+##            ('test4.xls', 'arr', 'Third_sheet', 'C3:AB40');
+##   (which adds the contents of array arr (any type) to
+##    rangeC3:AB40 in worksheet 'Third_sheet' in file
+##    test4.xls and returns a logical True (= numerical 1)
+##    in 'status' if all went well) 
 ## @end example
 ##
 ## @seealso {xlsread, oct2xls, xls2oct, xlsopen, xlsclose, xlsfinfo}
@@ -124,6 +138,8 @@
 ## 2014-09-30 Substitute wide enough crange if no or empty range was supplied
 ## 2014-10-04 Fix unintended side effects of previous fix
 ## 2014-11-28 Be sure to provide numeric 1 for empty sheet name
+## 2015-03-06 Texinfo hader update
+##     ''     usage() replaced by error(), "\n"added to suppress traceback
 
 function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
 
@@ -131,7 +147,7 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
 
   ## Sanity checks
   if (nargin < 2)
-    usage ("Insufficient arguments - see 'help xlswrite'");
+    error ("Insufficient arguments - see 'help xlswrite'\n");
   elseif (! ischar (filename))
     error ("xlswrite: first argument must be a filename (incl. suffix)\n");
   elseif (nargin == 2)
